# 🏠 vacasa connect 🏠
---
[![PyPI version](https://badge.fury.io/py/vacasa.svg)](https://pypi.org/project/vacasa/)
[![Python version](https://img.shields.io/badge/python-3.x-brightgreen.svg)](https://pypi.org/project/vacasa/)

My `vacasa` package provides a simple Python interface to the [Vacasa](https://www.vacasa.com/) Connect [API](https://vacasa.docs.stoplight.io/).

## Installation
The easiest way to start using this package is to install it via [PyPI](https://pypi.python.org/pypi/vacasa) using `pip`:

`$pip install vacasa`

If you'd prefer to clone and install the repository manually, follow these steps:

1. Clone this repo:
`$git clone https://github.com/johnwmillr/VacasaConnectAPI.git`
2. Enter the cloned directory:
`$cd VacasaConnectAPI`
3. Install:
    `$python setup.py install`

## Usage
### API Key
You'll need an API key and secret from Vacasa to begin using their Connect API.

### Examples
Coming soon...

## Documentation
 - [Vacasa website](https://www.vacasa.com/)
 - [Connect API documentation](https://connect.vacasa.com/)

## Collaboration
Please feel free to collaborate with a pull request or by opening an issue.
